Properly renamed the name of an internal thread.

git-svn-id: https://svn.apache.org/repos/asf/felix/trunk@1062289 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/deploymentadmin/service/src/main/java/org/apache/felix/deploymentadmin/ExplodingOutputtingInputStream.java b/deploymentadmin/service/src/main/java/org/apache/felix/deploymentadmin/ExplodingOutputtingInputStream.java
index 2008bc4..a9c8ef8 100644
--- a/deploymentadmin/service/src/main/java/org/apache/felix/deploymentadmin/ExplodingOutputtingInputStream.java
+++ b/deploymentadmin/service/src/main/java/org/apache/felix/deploymentadmin/ExplodingOutputtingInputStream.java
@@ -42,7 +42,7 @@
 import java.util.zip.ZipInputStream;
 
 /**
  * This class will write all entries encountered in an inputstream to disk. An index of files written to disk is kept in an index file in the
  * order they were encountered. Each file is compressed using GZIP. All the work is done on a separate thread.
  */
 class ExplodingOutputtingInputStream extends OutputtingInputStream implements Runnable {
@@ -74,7 +74,7 @@
         m_contentDir = root;
         m_indexFile = index;
         m_input = new PipedInputStream(output);
-        m_task = new Thread(this, "LiQ - ExplodingIncomingThread");
+        m_task = new Thread(this, "Apache Felix DeploymentAdmin - ExplodingOutputtingInputStream");
         m_task.start();
     }
@@ -42,7 +42,7 @@
 
 /**
- * This class will write all entries encountered in an inputstream to disk. An index of files written to disk is kept in an index file in the
+ * This class will write all entries encountered in an input stream to disk. An index of files written to disk is kept in an index file in the
  * order they were encountered. Each file is compressed using GZIP. All the work is done on a separate thread.
  */